import webview


"""
This example demonstrates how to use a built-in http server to serve local files
"""
if __name__ == '__main__':
    webview.create_window('My first HTML5 application', 'assets/index.html', text_select=True)
    webview.start(http_server=True, debug=True)



import webview
from .util import run_test


def test_noresize():
    window = webview.create_window('Min size test', 'https://www.example.org',
                                   width=800, height=600, resizable=True, min_size=(400, 200))
    run_test(webview, window)





import webview

"""
This example demonstrates how to create a frameless window with a custom minimum
size.
"""

if __name__ == '__main__':
    # Create a resizable webview window with minimum size constraints
    webview.create_window('Frameless window',
                          'http://pywebview.flowrl.com/hello',
                          frameless=True)
    webview.start()



from distutils.core import setup

import sys
import os
import shutil


def tree(src):
    return [(root, map(lambda f: os.path.join(root, f), filter(lambda f: os.path.splitext(f)[1] != ".map", files))) for (root, dirs, files) in os.walk(os.path.normpath(src))]


APP = ['start.py']
DATA_FILES = tree('assets')
OPTIONS_OSX = {'argv_emulation': False,
               'strip': True,
               'includes': ['WebKit', 'Foundation', 'webview']}

if os.path.exists('build'):
    shutil.rmtree('build')

if os.path.exists('dist'):
    shutil.rmtree('dist')

if sys.platform == 'darwin':
    import py2app

    setup(
        app=APP,
        data_files=DATA_FILES,
        options={'py2app': OPTIONS_OSX},
        setup_requires=['py2app'],
    )



import webview
import time

"""
This example demonstrates how to create a topmost webview window.
"""

def deactivate(window):
    #window starts on top and is changed later
    time.sleep(5)
    window.on_top = False


if __name__ == '__main__':
    # Create webview window that stays on top of, or in front of, all other windows
    window = webview.create_window('Topmost window',
                          'https://pywebview.flowrl.com/hello',
                          on_top=True)
    webview.start(deactivate, window)



import webview
from time import sleep

"""
This example demonstrates how to move window programmatically
"""


def move(window):
    print('Window coordinates are ({0}, {1})'.format(window.x, window.y))

    sleep(2)
    window.move(200, 200)

    print('Window coordinates are ({0}, {1})'.format(window.x, window.y))



if __name__ == '__main__':
    window = webview.create_window('Move window example', html='<h1>Move window</h1>', x=100, y=100)
    webview.start(move, window)



# -*- coding: utf-8 -*-
import webview
from .util import run_test


def test_localization():
    localization = {
        'cocoa.menu.about': u'О программе',
        'cocoa.menu.services': u'Cлужбы',
        'cocoa.menu.view': u'Вид',
        'cocoa.menu.hide': u'Скрыть',
        'cocoa.menu.hideOthers': u'Скрыть остальные',
        'cocoa.menu.showAll': u'Показать все',
        'cocoa.menu.quit': u'Завершить',
        'cocoa.menu.fullscreen': u'Полнж',
        'windows.fileFilter.allFiles': u'Все файлы',
        'windows.fileFilter.otherFiles': u'Остальлные файльы',
        'linux.openFile': u'Открыть файл',
        'linux.openFiles': u'Открыть файлы',
        'linux.openFolder': u'Открыть папку',
        'linux.saveFile': u'Сохранить файл',
    }

    window = webview.create_window('Localization test', 'https://www.example.org')
    run_test(webview, window, start_args={'localization': localization})









# -*- coding: utf-8 -*-

import webview

"""
This example demonstrates how to localize GUI strings used by pywebview.
"""

if __name__ == '__main__':
    localization = {
        'global.saveFile': u'Сохранить файл',
        'cocoa.menu.about': u'О программе',
        'cocoa.menu.services': u'Cлужбы',
        'cocoa.menu.view': u'Вид',
        'cocoa.menu.hide': u'Скрыть',
        'cocoa.menu.hideOthers': u'Скрыть остальные',
        'cocoa.menu.showAll': u'Показать все',
        'cocoa.menu.quit': u'Завершить',
        'cocoa.menu.fullscreen': u'Перейти ',
        'windows.fileFilter.allFiles': u'Все файлы',
        'windows.fileFilter.otherFiles': u'Остальлные файльы',
        'linux.openFile': u'Открыть файл',
        'linux.openFiles': u'Открыть файлы',
        'linux.openFolder': u'Открыть папку',
    }

    webview.create_window('Localization Example', 'https://pywebview.flowrl.com/hello')
    webview.start(localization=localization)




import webview

"""
This example demonstrates how to create a full-screen webview window.
"""

if __name__ == '__main__':
    # Create a non-resizable webview window with 800x600 dimensions
    webview.create_window('Full-screen window',
                          'https://pywebview.flowrl.com/hello',
                          fullscreen=True)
    webview.start()



import webview

"""
This example demonstrates how to create a webview window with a custom minimum
size.
"""

if __name__ == '__main__':
    # Create a resizable webview window with minimum size constraints
    webview.create_window('Minimum window size',
                          'https://pywebview.flowrl.com/hello',
                          min_size=(400, 200))
    webview.start()


"""
Cocoa window cannot be destroyed programmatically, until it finishes processing a NSEvent
So we need to simulate a mouse movement in order to generate an event.
"""

from Quartz.CoreGraphics import CGEventCreateMouseEvent
from Quartz.CoreGraphics import CGEventCreate
from Quartz.CoreGraphics import CGEventGetLocation
from Quartz.CoreGraphics import CFRelease
from Quartz.CoreGraphics import CGEventPost
from Quartz.CoreGraphics import kCGEventMouseMoved
from Quartz.CoreGraphics import kCGEventLeftMouseDown
from Quartz.CoreGraphics import kCGEventLeftMouseUp
from Quartz.CoreGraphics import kCGMouseButtonLeft
from Quartz.CoreGraphics import kCGHIDEventTap


def mousePos():
    event = CGEventCreate(None)
    pointer = CGEventGetLocation(event)
    #CFRelease(event)
    return pointer.x, pointer.y


def mouseEvent(type, posx, posy):
    theEvent = CGEventCreateMouseEvent(None, type, (posx, posy), kCGMouseButtonLeft)
    CGEventPost(kCGHIDEventTap, theEvent)


def mouseMove(posx, posy):
    mousePos()
    mouseEvent(kCGEventMouseMoved, posx, posy)


def mouseMoveRelative(dx, dy):
    posx, posy = mousePos()
    mouseMove(posx + dx, posy + dy)


def mouseclick(posx, posy):
    mouseEvent(kCGEventLeftMouseDown, posx, posy)
    mouseEvent(kCGEventLeftMouseUp, posx, posy)


if __name__ == '__main__':
    mouseMoveRelative(100, 100)


import webview
import pytest
from .util import run_test


def test_bg_color():
    window = webview.create_window('Background color test', 'https://www.example.org', background_color='#0000FF')
    run_test(webview, window)


def test_invalid_bg_color():
    with pytest.raises(ValueError):
        webview.create_window('Background color test', 'https://www.example.org', background_color='#dsg0000FF')

    with pytest.raises(ValueError):
        webview.create_window('Background color test', 'https://www.example.org', background_color='FF00FF')

    with pytest.raises(ValueError):
        webview.create_window('Background color test', 'https://www.example.org', background_color='#ac')

    with pytest.raises(ValueError):
        webview.create_window('Background color test', 'https://www.example.org', background_color='#EFEFEH')

    with pytest.raises(ValueError):
        webview.create_window('Background color test', 'https://www.example.org', background_color='#0000000')






import io
import wsgiref.util

from webview.wsgi import send_simple_text, Routing, StaticContentsApp


def make_wsgi_get(app, path):
    environ = {
        'SCRIPT_NAME': '',
        'PATH_INFO': path
    }
    wsgiref.util.setup_testing_defaults(environ)

    resp_status = None

    def sr(status, headers):
        nonlocal resp_status
        resp_status = status

    resp_body = b''.join(app(environ, sr))
    return resp_status, resp_body


def basic_app(response):
    def app(environ, start_response):
        return send_simple_text(environ, start_response, "200 OK", response)

    return app


def test_routing_simple():
    app = Routing({
        '/': basic_app("root"),
        '/spam': basic_app("spam"),
        '/eggs': basic_app("eggs"),
        '/spam/eggs': basic_app("vikings"),
    })

    assert make_wsgi_get(app, "/") == ('200 OK', b'root')
    assert make_wsgi_get(app, "/spam") == ('200 OK', b'spam')
    assert make_wsgi_get(app, "/eggs") == ('200 OK', b'eggs')
    assert make_wsgi_get(app, "/spam/eggs") == ('200 OK', b'vikings')
    assert make_wsgi_get(app, "/nope") == ('200 OK', b'root')


def test_routing_404():
    app = Routing({
        '/spam': basic_app("spam"),
        '/eggs': basic_app("eggs"),
    })

    assert make_wsgi_get(app, "/spam") == ('200 OK', b'spam')
    assert make_wsgi_get(app, "/eggs") == ('200 OK', b'eggs')
    assert make_wsgi_get(app, "/nope")[0] == '404 Not Found'


def test_basic_static():
    class Echo(StaticContentsApp):
        def open(self, path):
            return io.BytesIO(path.encode('utf-8'))

    app = Echo()

    assert make_wsgi_get(app, "/spam") == ('200 OK', b'/spam')
    assert make_wsgi_get(app, "/eggs") == ('200 OK', b'/eggs')
    assert make_wsgi_get(app, "/foo.txt") == ('200 OK', b'/foo.txt')



import webview

"""
This example demonstrates how to expose Python functions to the Javascript domain.
"""


def lol():
  print('LOL')


def wtf():
  print('WTF')


def echo(arg1, arg2, arg3):
  print(arg1)
  print(arg2)
  print(arg3)


def expose(window):
  window.expose(echo) # expose a function during the runtime

  window.evaluate_js('pywebview.api.lol()')
  window.evaluate_js('pywebview.api.wtf()')
  window.evaluate_js('pywebview.api.echo(1, 2, 3)')


if __name__ == '__main__':
    window = webview.create_window('JS Expose Example', html='<html><head></head><body><h1>JS Expost</body></html>')
    window.expose(lol, wtf) # expose functions beforehand

    webview.start(expose, window, debug=True)


import webview
from .util import run_test
from time import sleep


def test_resize():
    window = webview.create_window('Set Window Size Test', 'https://www.example.org', width=800, height=600)
    run_test(webview, window, resize)


def resize(window):
    assert window.width == 800
    assert window.height == 600

    window.resize(500, 500)

    sleep(0.5)

    assert window.width == 500
    assert window.height == 500



import webview
import threading
import time

"""
This example demonstrates how to change a window title.
"""


def change_title(window):
    """changes title every 3 seconds"""
    for i in range(1, 100):
        time.sleep(3)
        window.set_title('New Title #{}'.format(i))


if __name__ == '__main__':
    window = webview.create_window('Change title example', 'https://pywebview.flowrl.com/hello')
    webview.start(change_title, window)


import webview

"""
This example demonstrates how to enable debugging of webview content. To open
up debugging console, right click on an element and select Inspect.
"""

if __name__ == '__main__':
    webview.create_window('Debug window', 'https://pywebview.flowrl.com/hello')
    webview.start(debug=True)



import webview

"""
This example demonstrates how to create a CEF window. Available only on Windows.
"""

# To pass custom settings to CEF, import and update settings dict
from webview.platforms.cef import settings
settings.update({
    'persist_session_cookies': True
})

if __name__ == '__main__':
    webview.create_window('CEF browser', 'https://pywebview.flowrl.com/hello')
    webview.start(gui='cef')



import logging
import webview

from contextlib import redirect_stdout
from io import StringIO
from server import server

logger = logging.getLogger(__name__)


if __name__ == '__main__':

    stream = StringIO()
    with redirect_stdout(stream):
        window = webview.create_window('My first pywebview application', server)
        webview.start(debug=True)



import webview
import time
"""
This example demonstrates how to handle pywebview events.
"""

def on_closed():
    print('pywebview window is closed')


def on_closing():
    print('pywebview window is closing')


def on_shown():
    print('pywebview window shown')


def on_loaded():
    print('DOM is ready')

    # unsubscribe event listener
    webview.windows[0].loaded -= on_loaded
    webview.windows[0].load_url('https://pywebview.flowrl.com/hello')


if __name__ == '__main__':
    window = webview.create_window('Simple browser', 'https://pywebview.flowrl.com/', confirm_close=True)
    window.closed += on_closed
    window.closing += on_closing
    window.shown += on_shown
    window.loaded += on_loaded
    webview.start()



import pytest
import threading
from .util import run_test, get_test_name
import webview


@pytest.fixture
def window():
    return webview.create_window('Evaluate JS test')


def test_mixed(window):
    run_test(webview, window, mixed_test)


def test_array(window):
    run_test(webview, window, array_test)


def test_object(window):
    run_test(webview, window, object_test)


def test_string(window):
    run_test(webview, window, string_test)


def test_int(window):
    run_test(webview, window, int_test)


def test_float(window):
    run_test(webview, window, float_test)


def test_undefined(window):
    run_test(webview, window, undefined_test)


def test_null(window):
    run_test(webview, window, null_test)


def test_nan(window):
    run_test(webview, window, nan_test)


def mixed_test(window):
    result = window.evaluate_js("""
        document.body.style.backgroundColor = '#212121';
        // comment
        function test() {
            return 2 + 2;
        }
        test();
    """)
    assert result == 4


def array_test(window):
    result = window.evaluate_js("""
    function getValue() {
        return [undefined, 1, 'two', 3.00001, {four: true}]
    }
    getValue()
    """)
    assert result == [None, 1, 'two', 3.00001, {'four': True}]


def object_test(window):
    result = window.evaluate_js("""
    function getValue() {
        return {1: 2, 'test': true, obj: {2: false, 3: 3.1}}
    }

    getValue()
    """)
    assert result == {'1': 2, 'test': True, 'obj': {'2': False, '3': 3.1}}


def string_test(window):
    result = window.evaluate_js("""
    function getValue() {
        return "this is only a test"
    }

    getValue()
    """)
    assert result == u'this is only a test'


def int_test(window):
    result = window.evaluate_js("""
    function getValue() {
        return 23
    }

    getValue()
    """)
    assert result == 23


def float_test(window):
    result = window.evaluate_js("""
    function getValue() {
        return 23.23443
    }

    getValue()
    """)
    assert result == 23.23443


def undefined_test(window):
    result = window.evaluate_js("""
    function getValue() {
        return undefined
    }

    getValue()
    """)
    assert result is None


def null_test(window):
    result = window.evaluate_js("""
    function getValue() {
        return null
    }

    getValue()
    """)
    assert result is None


def nan_test(window):
    result = window.evaluate_js("""
    function getValue() {
        return NaN
    }

    getValue()
    """)
    assert result is None



import webview

"""
This example demonstrates a webview window with a quit confirmation dialog.
"""

if __name__ == '__main__':
    # Create a standard webview window
    webview.create_window('Confirm Quit Example',
                          'https://pywebview.flowrl.com/hello',
                          confirm_close=True)
    webview.start()



import webview

"""
This example demonstrates how to create a pywebview windows using QT
(normally GTK is preferred)
"""

if __name__ == '__main__':
    # Create a non-resizable webview window with 800x600 dimensions
    webview.create_window('Qt Example', 'http://flowrl.com')
    webview.start(gui='qt')